@@ -4,16 +4,16 @@ Information about this python-fedora release
 
 
 NAME = 'python-fedora'
-VERSION = '0.3.36'
+VERSION = '0.4.0'
 DESCRIPTION = 'Python modules for interacting with Fedora Services'
 LONG_DESCRIPTION = '''
 The Fedora Project runs many different services.  These services help us to
 package software, develop new programs, and generally put together the distro.
 This package contains software that helps us do that.
 '''
-AUTHOR = 'Toshio Kuratomi, Luke Macken, Ricky Elrod'
-EMAIL = 'tkuratom@redhat.com'
-COPYRIGHT = '2007-2013 Red Hat, Inc.'
+AUTHOR = 'Toshio Kuratomi, Luke Macken, Ricky Elrod, Ralph Bean'
+EMAIL = 'admin@fedoraproject.org'
+COPYRIGHT = '2007-2015 Red Hat, Inc.'
 URL = 'https://fedorahosted.org/python-fedora'
 DOWNLOAD_URL = 'https://fedorahosted.org/releases/p/y/python-fedora/'
 LICENSE = 'LGPLv2+'
